<?php
require get_template_directory() . '/inc/helpers.php';
require get_template_directory() . '/inc/sanitization.php';
require get_template_directory() . '/inc/functions.php';
require get_template_directory() . '/inc/helpers-post-meta.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/customizer-styles.php';

require get_template_directory() . '/inc/custom-fields-post.php';
require get_template_directory() . '/inc/custom-fields-page.php';
require get_template_directory() . '/inc/custom-fields-service.php';
require get_template_directory() . '/inc/custom-fields-project.php';
require get_template_directory() . '/inc/custom-fields-team.php';
require get_template_directory() . '/inc/custom-fields-diy.php';
require get_template_directory() . '/inc/custom-fields-faq.php';

add_action( 'after_setup_theme', 'technico_content_width', 0 );
function technico_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'technico_content_width', 848 );
}

add_action( 'after_setup_theme', 'technico_setup' );
if( !function_exists( 'technico_setup' ) ) :
function technico_setup() {

	if ( ! defined( 'CI_THEME_NAME' ) ) {
		define( 'CI_THEME_NAME', 'technico' );
	}
	if ( ! defined( 'CI_WHITELABEL' ) ) {
		// Set the following to true, if you want to remove any user-facing CSSIgniter traces.
		define( 'CI_WHITELABEL', false );
	}

	load_theme_textdomain( 'technico', get_template_directory() . '/languages' );

	/*
	 * Theme supports.
	 */
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_theme_support( 'custom-background' );

	add_theme_support( 'custom-logo', array(
		'height'      => 80,
		'width'       => 260,
		'flex-height' => true,
	) );

	/*
	 * Image sizes.
	 */
	set_post_thumbnail_size( 555, 350, true );
	add_image_size( 'technico_featured', 848, 450, true );
	add_image_size( 'technico_fullwidth', 1140, 450, true );
	add_image_size( 'technico_testimonial', 60, 60, true );
	add_image_size( 'technico_slide', 1920, 700, true );
	add_image_size( 'technico_client', 0, 80, false );


	/*
	 * Navigation menus.
	 */
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'technico' ),
	) );


	/*
	 * Default hooks
	 */
	// Prints the inline JS scripts that are registered for printing, and removes them from the queue.
	add_action( 'admin_footer', 'technico_print_inline_js' );
	add_action( 'wp_footer', 'technico_print_inline_js' );

	// Handle the dismissible sample content notice.
	add_action( 'admin_notices', 'technico_admin_notice_sample_content' );
	add_action( 'wp_ajax_technico_dismiss_sample_content', 'technico_ajax_dismiss_sample_content' );

	// Wraps post counts in span.ci-count
	// Needed for the default widgets, however more appropriate filters don't exist.
	add_filter( 'get_archives_link', 'technico_wrap_archive_widget_post_counts_in_span', 10, 2 );
	add_filter( 'wp_list_categories', 'technico_wrap_category_widget_post_counts_in_span', 10, 2 );
}
endif;



add_action( 'wp_enqueue_scripts', 'technico_enqueue_scripts' );
function technico_enqueue_scripts() {

	/*
	 * Styles
	 */
	$theme = wp_get_theme();

	$font_url = '';
	/* translators: If there are characters in your language that are not supported by Open Sans or Montserrat, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Open Sans and Montserrat font: on or off', 'technico' ) ) {
		$font_url = add_query_arg( 'family', 'Open+Sans:400,400italic,700%7CMontserrat:700&subset=latin,greek', '//fonts.googleapis.com/css' );
	}
	wp_register_style( 'technico-google-font', esc_url( $font_url ) );

	wp_register_style( 'technico-base', get_template_directory_uri() . '/css/base.css', array(), $theme->get( 'Version' ) );
	wp_register_style( 'flexslider', get_template_directory_uri() . '/css/flexslider.css', array(), '2.5.0' );
	wp_register_style( 'mmenu', get_template_directory_uri() . '/css/mmenu.css', array(), '5.5.3' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '4.7.0' );
	wp_register_style( 'magnific-popup', get_template_directory_uri() . '/css/magnific.css', array(), '1.0.0' );

	wp_register_style( 'technico-style', get_template_directory_uri() . '/style.css', array(
		'technico-google-font',
		'technico-base',
		'flexslider',
		'mmenu',
		'font-awesome',
		'magnific-popup',
	), $theme->get( 'Version' ) );

	if ( is_child_theme() ) {
		wp_register_style( 'technico-style-child', get_stylesheet_directory_uri() . '/style.css', array(
			'technico-style',
		), $theme->get( 'Version' ) );
	}

	/*
	 * Scripts
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_register_script( 'superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ), '1.7.5', true );
	wp_register_script( 'mmenu', get_template_directory_uri() . '/js/jquery.mmenu.min.all.js', array( 'jquery' ), '5.5.3', true );
	wp_register_script( 'flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array( 'jquery' ), '2.5.0', true );
	wp_register_script( 'fitVids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '1.1', true );
	wp_register_script( 'magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'match-height', get_template_directory_uri() . '/js/jquery.matchHeight.js', array( 'jquery' ), '1.0.0', true );

	wp_register_script( 'technico-front-scripts', get_template_directory_uri() . '/js/scripts.js', array(
		'jquery',
		'superfish',
		'mmenu',
		'flexslider',
		'fitVids',
		'magnific-popup',
		'match-height',
	), $theme->get( 'Version' ), true );


	/*
	 * Enqueue
	 */
	wp_enqueue_style( 'technico-style' );
	if ( is_child_theme() ) {
		wp_enqueue_style( 'technico-style-child' );
	}

	wp_enqueue_script( 'technico-front-scripts' );

}

add_action( 'admin_enqueue_scripts', 'technico_admin_enqueue_scripts' );
function technico_admin_enqueue_scripts( $hook ) {
	$theme = wp_get_theme();

	/*
	 * Styles
	 */
	wp_register_style( 'technico-repeating-fields', get_template_directory_uri() . '/css/admin/repeating-fields.css', array(), $theme->get( 'Version' ) );

	wp_register_style( 'technico-widgets', get_template_directory_uri() . '/css/admin/widgets.css', array(
		'wp-color-picker',
		'technico-repeating-fields',
		'technico-post-meta'
	), $theme->get( 'Version' ) );


	/*
	 * Scripts
	 */
	wp_register_script( 'technico-repeating-fields', get_template_directory_uri() . '/js/admin/repeating-fields.js', array(
		'jquery',
		'jquery-ui-sortable'
	), $theme->get( 'Version' ), true );

	wp_register_script( 'technico-widgets', get_template_directory_uri() . '/js/admin/widgets.js', array(
		'jquery',
		'wp-color-picker',
		'technico-repeating-fields',
		'technico-post-meta',
	), $theme->get( 'Version' ), true );
	$params = array(
		'no_posts_found' => esc_html__( 'No posts found.', 'technico' ),
		'ajaxurl'        => admin_url( 'admin-ajax.php' ),
	);
	wp_localize_script( 'technico-widgets', 'ThemeWidget', $params );


	/*
	 * Enqueue
	 */
	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'technico-post-meta' );
		wp_enqueue_script( 'technico-post-meta' );

		wp_enqueue_style( 'technico-repeating-fields' );
		wp_enqueue_script( 'technico-repeating-fields' );
	}

	if ( in_array( $hook, array( 'widgets.php', 'customize.php' ) ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'technico-widgets' );
		wp_enqueue_script( 'technico-widgets' );
	}

}


add_action( 'widgets_init', 'technico_widgets_init' );
function technico_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html_x( 'Blog', 'widget area', 'technico' ),
		'id'            => 'blog',
		'description'   => esc_html__( 'This is the main sidebar.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Pages', 'widget area', 'technico' ),
		'id'            => 'page',
		'description'   => esc_html__( 'This sidebar appears on your static pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Services', 'widget area', 'technico' ),
		'id'            => 'service',
		'description'   => esc_html__( 'This sidebar appears on your Services pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Projects', 'widget area', 'technico' ),
		'id'            => 'project',
		'description'   => esc_html__( 'This sidebar appears on your Projects pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Team', 'widget area', 'technico' ),
		'id'            => 'team',
		'description'   => esc_html__( 'This sidebar appears on your Team pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'DIY', 'widget area', 'technico' ),
		'id'            => 'diy',
		'description'   => esc_html__( 'This sidebar appears on your DIY pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'FAQ', 'widget area', 'technico' ),
		'id'            => 'faq',
		'description'   => esc_html__( 'This sidebar appears on your FAQ pages.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Homepage', 'widget area', 'technico' ),
		'id'            => 'homepage',
		'description'   => esc_html__( 'This widget area appears on your Homepage templates.', 'technico' ),
		'before_widget' => '<section id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="section-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #1', 'widget area', 'technico' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'This is the first column of widgets on the footer.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #2', 'widget area', 'technico' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'This is the second column of widgets on the footer.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #3', 'widget area', 'technico' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'This is the third column of widgets on the footer.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #4', 'widget area', 'technico' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'This is the fourth column of widgets on the footer.', 'technico' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}

add_action( 'widgets_init', 'technico_load_widgets' );
function technico_load_widgets() {
	require get_template_directory() . '/inc/widgets/slider.php';
	require get_template_directory() . '/inc/widgets/testimonials.php';
	require get_template_directory() . '/inc/widgets/clients.php';
	require get_template_directory() . '/inc/widgets/pricing-table.php';
	require get_template_directory() . '/inc/widgets/custom-content.php';
	require get_template_directory() . '/inc/widgets/latest-posts.php';
	require get_template_directory() . '/inc/widgets/post-type-items.php';

	require get_template_directory() . '/inc/widgets/socials.php';
	require get_template_directory() . '/inc/widgets/opening-hours.php';
	require get_template_directory() . '/inc/widgets/contact-info.php';
	require get_template_directory() . '/inc/widgets/technical-documentation.php';
	require get_template_directory() . '/inc/widgets/callout.php';
}

add_filter( 'excerpt_length', 'technico_excerpt_length' );
function technico_excerpt_length( $length ) {
	return get_theme_mod( 'excerpt_length', 55 );
}


add_filter( 'wp_page_menu', 'technico_wp_page_menu', 10, 2 );
function technico_wp_page_menu( $menu, $args ) {
	preg_match( '#^<div class="(.*?)">(?:.*?)</div>$#', $menu, $matches );
	$menu = preg_replace( '#^<div class=".*?">#', '', $menu, 1 );
	$menu = preg_replace( '#</div>$#', '', $menu, 1 );
	$menu = preg_replace( '#^<ul>#', '<ul class="' . esc_attr( $args['menu_class'] ) . '">', $menu, 1 );
	return $menu;
}


add_filter( 'the_content', 'technico_lightbox_rel', 12 );
add_filter( 'get_comment_text', 'technico_lightbox_rel' );
if ( ! function_exists( 'technico_lightbox_rel' ) ):
function technico_lightbox_rel( $content ) {
	global $post;
	$pattern     = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";
	$replacement = '<a$1href=$2$3.$4$5 data-lightbox="gal[' . $post->ID . ']"$6>$7</a>';
	$content     = preg_replace( $pattern, $replacement, $content );

	return $content;
}
endif;


if ( ! function_exists( 'technico_get_columns_classes' ) ):
function technico_get_columns_classes( $columns, $fullwidth = true ) {
	switch ( intval( $columns ) ) {
		case 3:
			$classes = 'col-lg-4 col-md-6 col-xs-12';
			if ( ! $fullwidth ) {
				$classes = 'col-xl-4 col-md-6 col-xs-12';
			}
			break;
		case 4:
			$classes = 'col-lg-3 col-md-6 col-xs-12';
			break;
		case 2:
		default:
			$classes = 'col-md-6 col-xs-12';
			break;
	}

	return apply_filters( 'technico_get_columns_classes', $classes, $columns, $fullwidth );
}
endif;

if ( ! function_exists( 'technico_best_number_of_columns' ) ):
function technico_best_number_of_columns( $count ) {
	$columns = apply_filters( 'technico_best_number_of_columns_default', 3 );

	if ( $count >= 1 && $count <= 4 ) {
		$columns = intval( $count );
	} elseif ( $count > 4 ) {
		if ( ( $count % 4 ) == 0 ) {
			$columns = 4;
		} elseif ( ( $count % 3 ) == 0 ) {
			$columns = 3;
		} elseif ( ( $count % 2 ) == 0 ) {
			$columns = 2;
		}
	}

	return apply_filters( 'technico_best_number_of_columns', $columns, $count );
}
endif;

if ( ! function_exists( 'technico_get_listing_layouts' ) ):
function technico_get_listing_layouts() {
	// The array keys MUST be comprised of two parts, separated by a dash.
	// First is the number of columns, followed by sidebar or fullwidth.
	// These are broken down within the templates to display things appropriately.
	return apply_filters( 'technico_listing_layouts', array(
		'2-sidebar'   => esc_html__( '2 Columns with Sidebar', 'technico' ),
		'3-sidebar'   => esc_html__( '3 Columns with Sidebar', 'technico' ),
		'2-fullwidth' => esc_html__( '2 Columns Full width', 'technico' ),
		'3-fullwidth' => esc_html__( '3 Columns Full width', 'technico' ),
		'4-fullwidth' => esc_html__( '4 Columns Full width', 'technico' ),
	) );
}
endif;

if ( ! function_exists( 'technico_get_listing_item_layouts' ) ):
function technico_get_listing_item_layouts( $post_type ) {
	$layouts = array();

	$defaults = array(
		'nothumb-nobutton'     => esc_html_x( 'Title - Text', 'item layout', 'technico' ),
		'nothumb'              => esc_html_x( 'Title - Text - Button', 'item layout', 'technico' ),
		'thumb-nobutton'       => esc_html_x( 'Image - Title - Text', 'item layout', 'technico' ),
		'thumb-notext'         => esc_html_x( 'Image - Title - Date - Button', 'item layout', 'technico' ),
		'thumb'                => esc_html_x( 'Image - Title - Date - Text - Button', 'item layout', 'technico' ),
		'icon-left'            => esc_html_x( 'Icon Left - Button', 'item layout', 'technico' ),
		'icon-left-nobutton'   => esc_html_x( 'Icon Left', 'item layout', 'technico' ),
		'icon-center'          => esc_html_x( 'Icon Centered - Button', 'item layout', 'technico' ),
		'icon-center-nobutton' => esc_html_x( 'Icon Centered', 'item layout', 'technico' ),
		'social'               => esc_html_x( 'Social', 'item layout', 'technico' ),
	);

	switch ( $post_type ) {
		case 'technico_team':
			$layouts['social'] = $defaults['social'];
			break;
		case 'technico_service':
			$layouts['icon-left']            = $defaults['icon-left'];
			$layouts['icon-left-nobutton']   = $defaults['icon-left-nobutton'];
			$layouts['icon-center']          = $defaults['icon-center'];
			$layouts['icon-center-nobutton'] = $defaults['icon-center-nobutton'];
			$layouts['thumb-nobutton']       = $defaults['thumb-nobutton'];
			break;
		case 'post':
		case 'page':
		case 'technico_diy':
		case 'technico_project':
		default:
			$layouts['nothumb-nobutton'] = $defaults['nothumb-nobutton'];
			$layouts['nothumb']          = $defaults['nothumb'];
			$layouts['thumb-nobutton']   = $defaults['thumb-nobutton'];
			$layouts['thumb-notext']     = $defaults['thumb-notext'];
			$layouts['thumb']            = $defaults['thumb'];
	}

	return apply_filters( 'technico_listing_item_layouts', $layouts, $post_type, $defaults );
}
endif;

if ( ! function_exists( 'technico_get_social_networks') ):
function technico_get_social_networks() {
	return apply_filters( 'technico_social_networks', array(
		array(
			'name'  => 'facebook',
			'label' => esc_html__( 'Facebook', 'technico' ),
			'icon'  => 'fa-facebook'
		),
		array(
			'name'  => 'twitter',
			'label' => esc_html__( 'Twitter', 'technico' ),
			'icon'  => 'fa-twitter'
		),
		array(
			'name'  => 'pinterest',
			'label' => esc_html__( 'Pinterest', 'technico' ),
			'icon'  => 'fa-pinterest'
		),
		array(
			'name'  => 'instagram',
			'label' => esc_html__( 'Instagram', 'technico' ),
			'icon'  => 'fa-instagram'
		),
		array(
			'name'  => 'gplus',
			'label' => esc_html__( 'Google Plus', 'technico' ),
			'icon'  => 'fa-google-plus'
		),
		array(
			'name'  => 'linkedin',
			'label' => esc_html__( 'LinkedIn', 'technico' ),
			'icon'  => 'fa-linkedin'
		),
		array(
			'name'  => 'tumblr',
			'label' => esc_html__( 'Tumblr', 'technico' ),
			'icon'  => 'fa-tumblr'
		),
		array(
			'name'  => 'flickr',
			'label' => esc_html__( 'Flickr', 'technico' ),
			'icon'  => 'fa-flickr'
		),
		array(
			'name'  => 'bloglovin',
			'label' => esc_html__( 'Bloglovin', 'technico' ),
			'icon'  => 'fa-heart'
		),
		array(
			'name'  => 'youtube',
			'label' => esc_html__( 'YouTube', 'technico' ),
			'icon'  => 'fa-youtube'
		),
		array(
			'name'  => 'vimeo',
			'label' => esc_html__( 'Vimeo', 'technico' ),
			'icon'  => 'fa-vimeo'
		),
		array(
			'name'  => 'dribbble',
			'label' => esc_html__( 'Dribbble', 'technico' ),
			'icon'  => 'fa-dribbble'
		),
		array(
			'name'  => 'wordpress',
			'label' => esc_html__( 'WordPress', 'technico' ),
			'icon'  => 'fa-wordpress'
		),
		array(
			'name'  => '500px',
			'label' => esc_html__( '500px', 'technico' ),
			'icon'  => 'fa-500px'
		),
		array(
			'name'  => 'soundcloud',
			'label' => esc_html__( 'Soundcloud', 'technico' ),
			'icon'  => 'fa-soundcloud'
		),
		array(
			'name'  => 'spotify',
			'label' => esc_html__( 'Spotify', 'technico' ),
			'icon'  => 'fa-spotify'
		),
		array(
			'name'  => 'vine',
			'label' => esc_html__( 'Vine', 'technico' ),
			'icon'  => 'fa-vine'
		),
	) );
}
endif;


if ( ! function_exists( 'technico_get_fullwidth_sidebars' ) ):
function technico_get_fullwidth_sidebars() {
	return apply_filters( 'technico_get_fullwidth_sidebars', array(
		'homepage',
	) );
}
endif;


add_action( 'wp_head', 'technico_print_google_analytics_tracking' );
if ( ! function_exists( 'technico_print_google_analytics_tracking' ) ):
function technico_print_google_analytics_tracking() {
	if ( is_admin() || ! get_theme_mod( 'google_anaytics_tracking_id' ) ) {
		return;
	}
	?>
	<script>
		(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
		(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
		m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
		})(window,document,'script','//www.google-analytics.com/analytics.js','ga');

		ga('create', '<?php echo get_theme_mod( 'google_anaytics_tracking_id' ); ?>', 'auto');
		ga('send', 'pageview');
	</script>
	<?php
}
endif;


add_filter( 'technico_pagination_default_args', 'technico_pagination_default_args' );
if ( ! function_exists( 'technico_pagination_default_args' ) ):
function technico_pagination_default_args( $args ) {
	$args['container_id']    = '';
	$args['container_class'] = 'paging';

	return $args;
}
endif;


if ( ! function_exists( 'technico_sanitize_footer_text' ) ):
function technico_sanitize_footer_text( $text ) {
	return wp_kses( $text, technico_get_allowed_tags( 'guide' ) );
}
endif;

if ( ! function_exists( 'technico_get_default_footer_text' ) ):
function technico_get_default_footer_text( $position = '' ) {
	if ( ! defined( 'CI_WHITELABEL' ) || ! CI_WHITELABEL ) {
		if ( $position == 'right' ) {
			$text = sprintf( __( 'Handcrafted by <a href="%s">CSSIgniter.com</a>', 'technico' ),
				esc_url( 'http://www.cssigniter.com/ignite/' )
			);
		} else {
			$text = sprintf( __( '<a href="%s">Technico</a> &ndash; Business Theme for WordPress', 'technico' ),
				esc_url( 'http://www.cssigniter.com/ignite/themes/technico/' )
			);
		}
	} else {
		if ( $position == 'right' ) {
			$text = sprintf( __( 'Powered by <a href="%s">WordPress</a>', 'technico' ),
				esc_url( 'https://wordpress.org/' )
			);
		} else {
			$text = sprintf( '<a href="%1$s">%2$s</a>',
				esc_url( home_url( '/' ) ),
				get_bloginfo( 'name' )
			);
		}
	}

	return $text;
}
endif;

/**
 * Theme Elements
 */
if ( defined( 'ELEMENTOR_VERSION' ) && version_compare( PHP_VERSION, '5.4', '>=' ) ) {
	require_once( 'inc/elements.php' );
}

function technico_post_types() {
	$post_types_available = get_post_types( array( 'public' => true ), 'objects' );
	unset( $post_types_available['attachment'] );
	if ( post_type_exists( 'elementor_library' ) ) {
		unset( $post_types_available['elementor_library'] );
	}

	$technico_pt[] = '';

	foreach ( $post_types_available as $key => $pt ) {
		$technico_pt[ $key ] = $pt->label;
	}

	return $technico_pt;
}

add_action( 'wp_ajax_technico_get_posts', 'ajax_technico_posts' );
function ajax_technico_posts() {

	// Verify nonce
	if ( ! isset( $_POST['technico_post_nonce'] ) || ! wp_verify_nonce( $_POST['technico_post_nonce'], 'technico_post_nonce' ) ) {
		die( 'Permission denied' );
	}

	$post_type = $_POST['post_type'];

	$q = new WP_Query( array(
		'post_type' => $post_type,
		'posts_per_page' => -1,
	) );
	?>

	<option><?php esc_html_e( 'Select an item', 'technico' ); ?></option>

	<?php while ( $q->have_posts() ) : $q->the_post(); ?>
		<option value="<?php echo esc_attr( get_the_ID() ); ?>"><?php the_title(); ?></option>
		<?php
	endwhile;
	wp_reset_postdata();
	wp_die();
}



if ( ! defined( 'CI_THEME_WHITELABEL' ) || false === (bool) CI_THEME_WHITELABEL ) {
	add_filter( 'pt-ocdi/import_files', 'technico_ocdi_import_files' );
	add_action( 'pt-ocdi/after_import', 'technico_ocdi_after_import_setup' );
}

function technico_ocdi_import_files( $files ) {
	if ( ! defined( 'CI_THEME_NAME' ) ) {
		define( 'CI_THEME_NAME', 'technico' );
	}

	$demo_dir_url = untrailingslashit( apply_filters( 'technico_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . CI_THEME_NAME ) );

	// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
	$new_files = array(
		array(
			'import_file_name'           => esc_html__( 'Demo Import', 'technico' ),
			'import_file_url'            => $demo_dir_url . '/content.xml',
			'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			'import_customizer_file_url' => $demo_dir_url . '/customizer.dat',
		),
	);

	return array_merge( $files, $new_files );
}

function technico_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu = get_term_by( 'name', 'Main', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'main_menu' => $main_menu->term_id,
	) );

	// Set up home and blog pages.
	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );
}
