<?php
	add_action( 'init', 'technico_create_project' );

	if ( ! function_exists( 'technico_create_project' ) ):
	function technico_create_project() {
		$labels = array(
			'name'               => esc_html_x( 'Projects', 'post type general name', 'technico' ),
			'singular_name'      => esc_html_x( 'Project', 'post type singular name', 'technico' ),
			'menu_name'          => esc_html_x( 'Projects', 'admin menu', 'technico' ),
			'name_admin_bar'     => esc_html_x( 'Project', 'add new on admin bar', 'technico' ),
			'add_new'            => esc_html__( 'Add New', 'technico' ),
			'add_new_item'       => esc_html__( 'Add New Project', 'technico' ),
			'edit_item'          => esc_html__( 'Edit Project', 'technico' ),
			'new_item'           => esc_html__( 'New Project', 'technico' ),
			'view_item'          => esc_html__( 'View Project', 'technico' ),
			'search_items'       => esc_html__( 'Search Projects', 'technico' ),
			'not_found'          => esc_html__( 'No Projects found', 'technico' ),
			'not_found_in_trash' => esc_html__( 'No Projects found in the trash', 'technico' ),
			'parent_item_colon'  => esc_html__( 'Parent Project:', 'technico' )
		);

		$args = array(
			'labels'          => $labels,
			'singular_label'  => esc_html_x( 'Project', 'post type singular name', 'technico' ),
			'public'          => true,
			'show_ui'         => true,
			'capability_type' => 'post',
			'hierarchical'    => false,
			'has_archive'     => false,
			'rewrite'         => array( 'slug' => esc_html_x( 'project', 'post type slug', 'technico' ) ),
			'menu_position'   => 5,
			'supports'        => array( 'title', 'editor', 'thumbnail' ),
			'menu_icon'       => 'dashicons-portfolio'
		);

		register_post_type( 'technico_project', $args );

		$labels = array(
			'name'              => esc_html_x( 'Project Categories', 'taxonomy general name', 'technico' ),
			'singular_name'     => esc_html_x( 'Project Category', 'taxonomy singular name', 'technico' ),
			'search_items'      => esc_html__( 'Search Project Categories', 'technico' ),
			'all_items'         => esc_html__( 'All Project Categories', 'technico' ),
			'parent_item'       => esc_html__( 'Parent Project Category', 'technico' ),
			'parent_item_colon' => esc_html__( 'Parent Project Category:', 'technico' ),
			'edit_item'         => esc_html__( 'Edit Project Category', 'technico' ),
			'update_item'       => esc_html__( 'Update Project Category', 'technico' ),
			'add_new_item'      => esc_html__( 'Add New Project Category', 'technico' ),
			'new_item_name'     => esc_html__( 'New Project Category Name', 'technico' ),
			'menu_name'         => esc_html__( 'Categories', 'technico' ),
			'view_item'         => esc_html__( 'View Project Category', 'technico' ),
			'popular_items'     => esc_html__( 'Popular Project Categories', 'technico' ),
		);
		register_taxonomy( 'technico_project_category', array( 'technico_project' ), array(
			'labels'            => $labels,
			'hierarchical'      => true,
			'show_admin_column' => true,
			'rewrite'           => array( 'slug' => esc_html_x( 'project-category', 'taxonomy slug', 'technico' ) ),
		) );

	}
	endif;

	add_action( 'admin_init', 'technico_cpt_project_add_metaboxes' );
	add_action( 'save_post', 'technico_cpt_project_update_meta' );

	if ( ! function_exists( 'technico_cpt_project_add_metaboxes' ) ):
	function technico_cpt_project_add_metaboxes() {
		add_meta_box( 'technico-project-box', esc_html__( 'Project Options', 'technico' ), 'technico_add_cpt_project_meta_box', 'technico_project', 'normal', 'high' );
	}
	endif;

	if ( ! function_exists( 'technico_cpt_project_update_meta' ) ):
	function technico_cpt_project_update_meta( $post_id ) {

		if ( ! technico_can_save_meta( 'technico_project' ) ) {
			return;
		}

		update_post_meta( $post_id, 'technico_hide_featured', technico_sanitize_checkbox_ref( $_POST['technico_hide_featured'] ) );
		update_post_meta( $post_id, 'technico_project_fields', technico_sanitize_project_fields_repeating( $_POST ) );
	}
	endif;

	if ( ! function_exists( 'technico_add_cpt_project_meta_box' ) ):
	function technico_add_cpt_project_meta_box( $object, $box ) {
		technico_prepare_metabox( 'technico_project' );

		?><div class="ci-cf-wrap"><?php
			technico_metabox_open_tab( '' );
				technico_metabox_checkbox( 'technico_hide_featured', 1, esc_html__( "Don't show the featured image when viewing this individual page.", 'technico' ) );

				technico_metabox_guide( array(
					wp_kses( __( 'You may include as many rows of information as you want. Press <em>Add Field</em> to add a new row. Press <em>Remove me</em> to delete a specific row. You can rearrange rows by drag and drop. You may leave empty the title or the description, but not both.', 'technico' ), technico_get_allowed_tags( 'guide' ) ),
					wp_kses( __( 'Allowed tags in description: a (href, class), span (class), i (class), b, em, strong. E.g.: <code>&lt;a href="#" class="btn">Button text&lt;/a></code>', 'technico' ), technico_get_allowed_tags( 'guide' ) ),
				), array( 'type' => 'p' ) );
				?>
				<fieldset class="ci-repeating-fields">
					<div class="inner">
						<?php
							$fields = get_post_meta( $object->ID, 'technico_project_fields', true );

							if ( ! empty( $fields ) ) {
								foreach ( $fields as $field ) {
									?>
									<div class="post-field">
										<label><?php esc_html_e( 'Title:', 'technico' ); ?> <input type="text" name="technico_project_fields_repeatable_title[]" value="<?php echo esc_attr( $field['title'] ); ?>" class="widefat" /></label>
										<label><?php esc_html_e( 'Description:', 'technico' ); ?> <input type="text" name="technico_project_fields_repeatable_description[]" value="<?php echo esc_attr( $field['description'] ); ?>" class="widefat" /></label>
										<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
									</div>
									<?php
								}
							}
							?>
							<div class="post-field field-prototype" style="display: none;">
								<label><?php esc_html_e( 'Title:', 'technico' ); ?> <input type="text" name="technico_project_fields_repeatable_title[]" value="" class="widefat" /></label>
								<label><?php esc_html_e( 'Description:', 'technico' ); ?> <input type="text" name="technico_project_fields_repeatable_description[]" value="" class="widefat" /></label>
								<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
							</div>
					</div>
					<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Field', 'technico' ); ?></a>
				</fieldset>
				<?php
			technico_metabox_close_tab();
		?></div><?php
	}
	endif;

	if ( ! function_exists( 'technico_sanitize_project_fields_repeating' ) ):
	function technico_sanitize_project_fields_repeating( $POST_array ) {
		if ( empty( $POST_array ) || ! is_array( $POST_array ) ) {
			return false;
		}

		$titles       = $POST_array['technico_project_fields_repeatable_title'];
		$descriptions = $POST_array['technico_project_fields_repeatable_description'];

		$count = max( count( $titles ), count( $descriptions ) );

		$new_fields = array();

		$records_count = 0;
		$allowed_html = array(
			'a'      => array(
				'href'  => array(),
				'class' => array(),
			),
			'span'   => array(
				'class' => array(),
			),
			'i'      => array(
				'class' => array(),
			),
			'b'      => array(),
			'em'     => array(),
			'strong' => array(),
		);

		for ( $i = 0; $i < $count; $i++ ) {
			if ( empty( $titles[ $i ] ) && empty( $descriptions[ $i ] ) ) {
				continue;
			}

			$new_fields[ $records_count ]['title']       = sanitize_text_field( $titles[ $i ] );
			$new_fields[ $records_count ]['description'] = wp_kses( $descriptions[ $i ], $allowed_html );
			$records_count++;
		}
		return $new_fields;
	}
	endif;
