<?php
	add_action( 'init', 'technico_create_service' );

	if ( ! function_exists( 'technico_create_service' ) ):
	function technico_create_service() {
		$labels = array(
			'name'               => esc_html_x( 'Services', 'post type general name', 'technico' ),
			'singular_name'      => esc_html_x( 'Service', 'post type singular name', 'technico' ),
			'menu_name'          => esc_html_x( 'Services', 'admin menu', 'technico' ),
			'name_admin_bar'     => esc_html_x( 'Service', 'add new on admin bar', 'technico' ),
			'add_new'            => esc_html__( 'Add New', 'technico' ),
			'add_new_item'       => esc_html__( 'Add New Service', 'technico' ),
			'edit_item'          => esc_html__( 'Edit Service', 'technico' ),
			'new_item'           => esc_html__( 'New Service', 'technico' ),
			'view_item'          => esc_html__( 'View Service', 'technico' ),
			'search_items'       => esc_html__( 'Search Services', 'technico' ),
			'not_found'          => esc_html__( 'No Services found', 'technico' ),
			'not_found_in_trash' => esc_html__( 'No Services found in the trash', 'technico' ),
			'parent_item_colon'  => esc_html__( 'Parent Service:', 'technico' )
		);

		$args = array(
			'labels'          => $labels,
			'singular_label'  => esc_html_x( 'Service', 'post type singular name', 'technico' ),
			'public'          => true,
			'show_ui'         => true,
			'capability_type' => 'post',
			'hierarchical'    => false,
			'has_archive'     => false,
			'rewrite'         => array( 'slug' => esc_html_x( 'service', 'post type slug', 'technico' ) ),
			'menu_position'   => 5,
			'supports'        => array( 'title', 'editor', 'thumbnail' ),
			'menu_icon'       => 'dashicons-star-filled'
		);

		register_post_type( 'technico_service', $args );

		$labels = array(
			'name'              => esc_html_x( 'Service Categories', 'taxonomy general name', 'technico' ),
			'singular_name'     => esc_html_x( 'Service Category', 'taxonomy singular name', 'technico' ),
			'search_items'      => esc_html__( 'Search Service Categories', 'technico' ),
			'all_items'         => esc_html__( 'All Service Categories', 'technico' ),
			'parent_item'       => esc_html__( 'Parent Service Category', 'technico' ),
			'parent_item_colon' => esc_html__( 'Parent Service Category:', 'technico' ),
			'edit_item'         => esc_html__( 'Edit Service Category', 'technico' ),
			'update_item'       => esc_html__( 'Update Service Category', 'technico' ),
			'add_new_item'      => esc_html__( 'Add New Service Category', 'technico' ),
			'new_item_name'     => esc_html__( 'New Service Category Name', 'technico' ),
			'menu_name'         => esc_html__( 'Categories', 'technico' ),
			'view_item'         => esc_html__( 'View Service Category', 'technico' ),
			'popular_items'     => esc_html__( 'Popular Service Categories', 'technico' ),
		);
		register_taxonomy( 'technico_service_category', array( 'technico_service' ), array(
			'labels'            => $labels,
			'hierarchical'      => true,
			'show_admin_column' => true,
			'rewrite'           => array( 'slug' => esc_html_x( 'service-category', 'taxonomy slug', 'technico' ) ),
		) );

	}
	endif;

	add_action( 'admin_init', 'technico_cpt_service_add_metaboxes' );
	add_action( 'save_post', 'technico_cpt_service_update_meta' );

	if ( ! function_exists( 'technico_cpt_service_add_metaboxes' ) ):
	function technico_cpt_service_add_metaboxes() {
		add_meta_box( 'technico-service-box', esc_html__( 'Service Options', 'technico' ), 'technico_add_cpt_service_meta_box', 'technico_service', 'normal', 'high' );
	}
	endif;

	if ( ! function_exists( 'technico_cpt_service_update_meta' ) ):
	function technico_cpt_service_update_meta( $post_id ) {

		if ( ! technico_can_save_meta( 'technico_service' ) ) {
			return;
		}

		update_post_meta( $post_id, 'technico_hide_featured', technico_sanitize_checkbox_ref( $_POST['technico_hide_featured'] ) );
		update_post_meta( $post_id, 'technico_icon', sanitize_html_class( $_POST['technico_icon'] ) );
	}
	endif;

	if ( ! function_exists( 'technico_add_cpt_service_meta_box' ) ):
	function technico_add_cpt_service_meta_box( $object, $box ) {
		technico_prepare_metabox( 'technico_service' );

		?><div class="ci-cf-wrap"><?php
			technico_metabox_open_tab( '' );
				technico_metabox_checkbox( 'technico_hide_featured', 1, esc_html__( "Don't show the featured image when viewing this individual page.", 'technico' ) );

				technico_metabox_guide( wp_kses( sprintf( __( 'In the following box, type the icon code that best describes your service, including the <em>fa-</em> prefix. E.g. <code>fa-gear</code>. <a href="%s" target="_blank">Reference</a>', 'technico' ), 'http://fontawesome.io/icons/' ), technico_get_allowed_tags( 'guide' ) ) );
				technico_metabox_input( 'technico_icon', __( 'Icon code:', 'technico' ) );
			technico_metabox_close_tab();
		?></div><?php
	}
	endif;

	if ( ! function_exists( 'technico_sanitize_service_fields_repeating' ) ):
	function technico_sanitize_service_fields_repeating( $POST_array ) {
		if ( empty( $POST_array ) || ! is_array( $POST_array ) ) {
			return false;
		}

		$titles       = $POST_array['technico_service_fields_repeatable_title'];
		$descriptions = $POST_array['technico_service_fields_repeatable_description'];

		$count = max( count( $titles ), count( $descriptions ) );

		$new_fields = array();

		$records_count = 0;
		$allowed_html = array(
			'a'      => array(
				'href'  => array(),
				'class' => array(),
			),
			'span'   => array(
				'class' => array(),
			),
			'i'      => array(
				'class' => array(),
			),
			'b'      => array(),
			'em'     => array(),
			'strong' => array(),
		);

		for ( $i = 0; $i < $count; $i++ ) {
			if ( empty( $titles[ $i ] ) && empty( $descriptions[ $i ] ) ) {
				continue;
			}

			$new_fields[ $records_count ]['title']       = sanitize_text_field( $titles[ $i ] );
			$new_fields[ $records_count ]['description'] = wp_kses( $descriptions[ $i ], $allowed_html );
			$records_count++;
		}
		return $new_fields;
	}
	endif;
