<?php
	add_action( 'init', 'technico_create_team' );

	if ( ! function_exists( 'technico_create_team' ) ):
	function technico_create_team() {
		$labels = array(
			'name'               => esc_html_x( 'Team', 'post type general name', 'technico' ),
			'singular_name'      => esc_html_x( 'Member', 'post type singular name', 'technico' ),
			'menu_name'          => esc_html_x( 'Team', 'admin menu', 'technico' ),
			'name_admin_bar'     => esc_html_x( 'Member', 'add new on admin bar', 'technico' ),
			'add_new'            => esc_html__( 'Add New', 'technico' ),
			'add_new_item'       => esc_html__( 'Add New Member', 'technico' ),
			'edit_item'          => esc_html__( 'Edit Member', 'technico' ),
			'new_item'           => esc_html__( 'New Member', 'technico' ),
			'view_item'          => esc_html__( 'View Member', 'technico' ),
			'search_items'       => esc_html__( 'Search Members', 'technico' ),
			'not_found'          => esc_html__( 'No Members found', 'technico' ),
			'not_found_in_trash' => esc_html__( 'No Members found in the trash', 'technico' ),
			'parent_item_colon'  => esc_html__( 'Parent Member:', 'technico' )
		);

		$args = array(
			'labels'          => $labels,
			'singular_label'  => esc_html_x( 'Member', 'post type singular name', 'technico' ),
			'public'          => true,
			'show_ui'         => true,
			'capability_type' => 'post',
			'hierarchical'    => false,
			'has_archive'     => false,
			'rewrite'         => array( 'slug' => esc_html_x( 'team', 'post type slug', 'technico' ) ),
			'menu_position'   => 5,
			'supports'        => array( 'title', 'editor', 'thumbnail' ),
			'menu_icon'       => 'dashicons-admin-users'
		);

		register_post_type( 'technico_team', $args );

		$labels = array(
			'name'              => esc_html_x( 'Team Categories', 'taxonomy general name', 'technico' ),
			'singular_name'     => esc_html_x( 'Team Category', 'taxonomy singular name', 'technico' ),
			'search_items'      => esc_html__( 'Search Team Categories', 'technico' ),
			'all_items'         => esc_html__( 'All Team Categories', 'technico' ),
			'parent_item'       => esc_html__( 'Parent Team Category', 'technico' ),
			'parent_item_colon' => esc_html__( 'Parent Team Category:', 'technico' ),
			'edit_item'         => esc_html__( 'Edit Team Category', 'technico' ),
			'update_item'       => esc_html__( 'Update Team Category', 'technico' ),
			'add_new_item'      => esc_html__( 'Add New Team Category', 'technico' ),
			'new_item_name'     => esc_html__( 'New Team Category Name', 'technico' ),
			'menu_name'         => esc_html__( 'Categories', 'technico' ),
			'view_item'         => esc_html__( 'View Team Category', 'technico' ),
			'popular_items'     => esc_html__( 'Popular Team Categories', 'technico' ),
		);
		register_taxonomy( 'technico_team_category', array( 'technico_team' ), array(
			'labels'            => $labels,
			'hierarchical'      => true,
			'show_admin_column' => true,
			'rewrite'           => array( 'slug' => esc_html_x( 'team-category', 'taxonomy slug', 'technico' ) ),
		) );

	}
	endif;

	add_action( 'admin_init', 'technico_cpt_team_add_metaboxes' );
	add_action( 'save_post', 'technico_cpt_team_update_meta' );

	if ( ! function_exists( 'technico_cpt_team_add_metaboxes' ) ):
	function technico_cpt_team_add_metaboxes() {
		add_meta_box( 'technico-team-box', esc_html__( 'Member Options', 'technico' ), 'technico_add_cpt_team_meta_box', 'technico_team', 'normal', 'high' );
	}
	endif;

	if ( ! function_exists( 'technico_cpt_team_update_meta' ) ):
	function technico_cpt_team_update_meta( $post_id ) {

		if ( ! technico_can_save_meta( 'technico_team' ) ) {
			return;
		}

		update_post_meta( $post_id, 'technico_hide_featured', technico_sanitize_checkbox_ref( $_POST['technico_hide_featured'] ) );
		update_post_meta( $post_id, 'technico_subtitle', sanitize_text_field( $_POST['technico_subtitle'] ) );
		update_post_meta( $post_id, 'technico_team_social_fields', technico_sanitize_team_social_fields_repeating( $_POST ) );
	}
	endif;

	if ( ! function_exists( 'technico_add_cpt_team_meta_box' ) ):
	function technico_add_cpt_team_meta_box( $object, $box ) {
		technico_prepare_metabox( 'technico_team' );

		?><div class="ci-cf-wrap"><?php
			technico_metabox_open_tab( '' );
				technico_metabox_checkbox( 'technico_hide_featured', 1, esc_html__( "Don't show the featured image when viewing this individual page.", 'technico' ) );
				technico_metabox_input( 'technico_subtitle', esc_html__( 'Subtitle (optional):', 'technico' ) );

				technico_metabox_guide( array(
					wp_kses( __( 'You may include as many social icons as you want. Press <em>Add Field</em> to add a new row. Press <em>Remove me</em> to delete a specific row. You can rearrange rows by drag and drop. You may leave empty the title or the description, but not both.', 'technico' ), technico_get_allowed_tags( 'guide' ) ),
					wp_kses( sprintf( __( 'In the <em>Icon code</em> box, type the icon code of the desired social network, including the <em>fa-</em> prefix. E.g. <code>fa-facebook</code>. <a href="%s" target="_blank">Reference</a>', 'technico' ), 'http://fontawesome.io/icons/#brand' ), technico_get_allowed_tags( 'guide' ) ),
				), array( 'type' => 'p' ) );
				?>
				<fieldset class="ci-repeating-fields">
					<div class="inner">
						<?php
							$fields = get_post_meta( $object->ID, 'technico_team_social_fields', true );

							if ( ! empty( $fields ) ) {
								foreach ( $fields as $field ) {
									?>
									<div class="post-field">
										<label><?php esc_html_e( 'Icon code:', 'technico' ); ?> <input type="text" name="technico_team_social_fields_repeatable_code[]" value="<?php echo esc_attr( $field['code'] ); ?>" class="widefat" /></label>
										<label><?php esc_html_e( 'URL:', 'technico' ); ?> <input type="text" name="technico_team_social_fields_repeatable_url[]" value="<?php echo esc_attr( $field['url'] ); ?>" class="widefat" /></label>
										<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
									</div>
									<?php
								}
							}
							?>
							<div class="post-field field-prototype" style="display: none;">
								<label><?php esc_html_e( 'Icon code:', 'technico' ); ?> <input type="text" name="technico_team_social_fields_repeatable_code[]" value="" class="widefat" /></label>
								<label><?php esc_html_e( 'URL:', 'technico' ); ?> <input type="text" name="technico_team_social_fields_repeatable_url[]" value="" class="widefat" /></label>
								<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
							</div>
					</div>
					<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Field', 'technico' ); ?></a>
				</fieldset>
				<?php
			technico_metabox_close_tab();
		?></div><?php
	}
	endif;

	if ( ! function_exists( 'technico_sanitize_team_social_fields_repeating' ) ):
	function technico_sanitize_team_social_fields_repeating( $POST_array ) {
		if ( empty( $POST_array ) || ! is_array( $POST_array ) ) {
			return false;
		}

		$codes = $POST_array['technico_team_social_fields_repeatable_code'];
		$urls  = $POST_array['technico_team_social_fields_repeatable_url'];

		$count = max( count( $codes ), count( $urls ) );

		$new_fields = array();

		$records_count = 0;

		for ( $i = 0; $i < $count; $i++ ) {
			if ( empty( $codes[ $i ] ) && empty( $urls[ $i ] ) ) {
				continue;
			}

			$new_fields[ $records_count ]['code'] = sanitize_html_class( $codes[ $i ] );
			$new_fields[ $records_count ]['url']  = esc_url_raw( $urls[ $i ] );
			$records_count++;
		}
		return $new_fields;
	}
	endif;
