<?php
add_action( 'customize_register', 'technico_customize_register', 100 );
/**
 * Registers all theme-related options to the Customizer.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function technico_customize_register( $wpc ) {

	$wpc->add_section( 'header', array(
		'title'    => esc_html_x( 'Header Options', 'customizer section title', 'technico' ),
		'priority' => 1
	) );

	$wpc->get_panel( 'nav_menus' )->priority = 2;

	$wpc->add_section( 'layout', array(
		'title'    => esc_html_x( 'Layout Options', 'customizer section title', 'technico' ),
		'priority' => 20
	) );

	$wpc->add_section( 'typography', array(
		'title'    => _x( 'Typography Options', 'customizer section title', 'technico' ),
		'priority' => 40
	) );

	$wpc->get_section( 'colors' )->title    = esc_html__( 'Content Colors', 'technico' );
	$wpc->get_section( 'colors' )->priority = 50;


	// The following line doesn't work in a some PHP versions. Apparently, get_panel( 'widgets' ) returns an array,
	// therefore a cast to object is needed. http://wordpress.stackexchange.com/questions/160987/warning-creating-default-object-when-altering-customize-panels
	//$wpc->get_panel( 'widgets' )->priority = 55;
	$panel_widgets = (object) $wpc->get_panel( 'widgets' );
	$panel_widgets->priority = 55;

	$wpc->add_section( 'sidebar_colors', array(
		'title'    => _x( 'Sidebar Colors', 'customizer section title', 'technico' ),
		'priority' => 60
	) );

	$wpc->add_section( 'social', array(
		'title'       => esc_html_x( 'Social Networks', 'customizer section title', 'technico' ),
		'description' => esc_html__( 'Enter your social network URLs. Leaving a URL empty will hide its respective icon.', 'technico' ),
		'priority'    => 70
	) );

	$wpc->add_panel( 'cpt_post_options', array(
		'title'       => esc_html_x( 'Post Options', 'customizer section title', 'technico' ),
		'description' => esc_html__( 'These options affect your post-related pages.', 'technico' ),
		'priority'    => 80
	) );

	$wpc->add_section( 'listing_post', array(
		'title' => esc_html_x( 'Post Listings', 'customizer section title', 'technico' ),
		'panel' => 'cpt_post_options',
	) );

	$wpc->add_section( 'single_post', array(
		'title' => esc_html_x( 'Single Posts', 'customizer section title', 'technico' ),
		'panel' => 'cpt_post_options',
	) );

	$wpc->add_panel( 'cpt_diy_options', array(
		'title'       => esc_html_x( 'DIY Options', 'customizer section title', 'technico' ),
		'description' => esc_html__( 'These options affect your DIY-related pages.', 'technico' ),
		'priority'    => 90
	) );

	$wpc->add_section( 'listing_diy', array(
		'title' => esc_html_x( 'DIY Listings', 'customizer section title', 'technico' ),
		'panel' => 'cpt_diy_options',
	) );

	$wpc->add_section( 'single_diy', array(
		'title' => esc_html_x( 'Single DIY', 'customizer section title', 'technico' ),
		'panel' => 'cpt_diy_options',
	) );

	$wpc->add_section( 'footer', array(
		'title'    => esc_html_x( 'Footer Options', 'customizer section title', 'technico' ),
		'priority' => 100
	) );

	// Section 'static_front_page' is not defined when there are no pages.
	if ( get_pages() ) {
		$wpc->get_section( 'static_front_page' )->priority = 110;
	}

	$wpc->add_section( 'titles', array(
		'title'    => esc_html_x( 'Titles', 'customizer section title', 'technico' ),
		'priority' => 120
	) );

	$wpc->add_section( 'other', array(
		'title'       => esc_html_x( 'Other', 'customizer section title', 'technico' ),
		'description' => esc_html__( 'Other options affecting the whole site.', 'technico' ),
		'priority'    => 130
	) );


	//
	// Group options by registering the setting first, and the control right after.
	//

	//
	// Header
	//
	$wpc->add_setting( 'header_address_text', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'header_address_text', array(
		'type'    => 'text',
		'section' => 'header',
		'label'   => esc_html__( 'Address text', 'technico' ),
	) );

	$wpc->add_setting( 'header_address_url', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'header_address_url', array(
		'type'        => 'text',
		'section'     => 'header',
		'label'       => esc_html__( 'Address URL (optional)', 'technico' ),
		'description' => esc_html__( 'You can provide a URL that the address will be linked to. For example, it can be to your contact page or to Google Maps.', 'technico' ),
	) );

	$wpc->add_setting( 'header_telephone_text', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'header_telephone_text', array(
		'type'    => 'text',
		'section' => 'header',
		'label'   => esc_html__( 'Telephone text', 'technico' ),
	) );

	$wpc->add_setting( 'header_telephone_url', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'header_telephone_url', array(
		'type'        => 'text',
		'section'     => 'header',
		'label'       => esc_html__( 'Telephone URI (optional)', 'technico' ),
		'description' => wp_kses( __( 'If you want the telephone to be clickable, provide its international format including the country code prefixed by a <strong>+</strong>. Hyphens, dots or parentheses may be used for visual separation, but no spaces. E.g. <strong>+1-234-567-890</strong>', 'technico' ), technico_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'header_socials', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_socials', array(
		'type'    => 'checkbox',
		'section' => 'header',
		'label'   => esc_html__( 'Show social icons.', 'technico' ),
	) );

	$wpc->add_setting( 'header_nav_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_nav_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Navigation Color', 'technico' ),
	) ) );

	$wpc->add_setting( 'header_nav_color_hover', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_nav_color_hover', array(
		'section' => 'header',
		'label'   => esc_html__( 'Navigation Hover/Active Color', 'technico' ),
	) ) );

	$wpc->add_setting( 'header_subnav_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_bg_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Sub-nav Background Color', 'technico' ),
	) ) );



	//
	// Layout
	//
	$wpc->add_setting( 'excerpt_length', array(
		'default'           => 55,
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( 'excerpt_length', array(
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 10,
			'step' => 1,
		),
		'section'     => 'layout',
		'label'       => esc_html__( 'Automatically generated excerpt length (in words)', 'technico' ),
	) );

	$wpc->add_setting( 'pagination_method', array(
		'default'           => 'numbers',
		'sanitize_callback' => 'technico_sanitize_pagination_method',
	) );
	$wpc->add_control( 'pagination_method', array(
		'type'    => 'select',
		'section' => 'layout',
		'label'   => esc_html__( 'Pagination method', 'technico' ),
		'choices' => array(
			'numbers' => esc_html_x( 'Numbered links', 'pagination method', 'technico' ),
			'text'    => esc_html_x( '"Previous - Next" links', 'pagination method', 'technico' ),
		),
	) );

	
	//
	// Typography
	//
	$wpc->add_setting( 'h1_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h1_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H1 size', 'technico' ),
	) );

	$wpc->add_setting( 'h2_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h2_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H2 size', 'technico' ),
	) );

	$wpc->add_setting( 'h3_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h3_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H3 size', 'technico' ),
	) );

	$wpc->add_setting( 'h4_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h4_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H4 size', 'technico' ),
	) );

	$wpc->add_setting( 'h5_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h5_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H5 size', 'technico' ),
	) );

	$wpc->add_setting( 'h6_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h6_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H6 size', 'technico' ),
	) );

	$wpc->add_setting( 'body_text_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'body_text_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Body text size', 'technico' ),
	) );

	$wpc->add_setting( 'widgets_title_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'widgets_title_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Widgets title size', 'technico' ),
	) );

	$wpc->add_setting( 'widgets_text_size', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'widgets_text_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Widgets text size', 'technico' ),
	) );


	//
	// Content colors
	//
	$wpc->get_control( 'background_image' )->section      = 'colors';
	$wpc->get_control( 'background_repeat' )->section     = 'colors';
	$wpc->get_control( 'background_attachment' )->section = 'colors';
	if ( ! is_null( $wpc->get_control( 'background_position_x' ) ) ) {
		$wpc->get_control( 'background_position_x' )->section = 'colors';
	} else {
		$wpc->get_control( 'background_position' )->section = 'colors';
		$wpc->get_control( 'background_preset' )->section   = 'colors';
		$wpc->get_control( 'background_size' )->section     = 'colors';
	}

	$wpc->add_setting( 'global_primary_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_primary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Primary color', 'technico' )
	) ) );

	$wpc->add_setting( 'text_on_primary_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'text_on_primary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text on Primary Color', 'technico' )
	) ) );

	$wpc->add_setting( 'global_secondary_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_secondary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Secondary Color', 'technico' )
	) ) );

	$wpc->add_setting( 'text_on_secondary_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'text_on_secondary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text on Secondary Color', 'technico' )
	) ) );

	$wpc->add_setting( 'global_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text Color (Content)', 'technico' )
	) ) );

	$wpc->add_setting( 'global_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_link_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Content Link Color', 'technico' )
	) ) );

	$wpc->add_setting( 'global_link_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_link_hover_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Content Link Hover Color', 'technico' )
	) ) );

	$wpc->add_setting( 'global_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_border_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Global Border Color', 'technico' )
	) ) );


	$wpc->add_setting( 'hero_area_bg_info', array(
		'default' => '',
	) );
	$wpc->add_control( new Technico_Customize_Static_Text_Control( $wpc, 'hero_area_bg_info', array(
		'section'     => 'colors',
		'label'       => esc_html__( 'Section Title', 'technico' ),
		'description' => array(
			esc_html__( 'The following options affect the section title area, just below your site\'s logo.', 'technico' ),
			esc_html__( 'While the area is affected by the primary colors set above, you may override them with a different set of colors', 'technico' ),
		),
	) ) );

	$wpc->add_setting( 'hero_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'hero_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text Color', 'technico' ),
	) ) );

	$wpc->add_setting( 'hero_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'hero_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Background Color', 'technico' ),
	) ) );

	$wpc->add_setting( 'hero_bg_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'hero_bg_image', array(
		'section'     => 'colors',
		'label'       => esc_html__( 'Background Image', 'technico' ),
	) ) );


	//
	// Sidebar colors
	//
	$wpc->add_setting( 'sidebar_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_bg_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Background color', 'technico' ),
	) ) );

	$wpc->add_setting( 'sidebar_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_text_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Text color', 'technico' ),
	) ) );

	$wpc->add_setting( 'sidebar_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_link_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Link color', 'technico' ),
	) ) );

	$wpc->add_setting( 'sidebar_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_hover_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Link Hover color', 'technico' ),
	) ) );

	$wpc->add_setting( 'sidebar_title_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_title_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Widget titles color', 'technico' ),
	) ) );

	$wpc->add_setting( 'sidebar_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'technico_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_border_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Border color', 'technico' ),
	) ) );



	//
	// Social
	//
	$wpc->add_setting( 'social_target', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'social_target', array(
		'type'    => 'checkbox',
		'section' => 'social',
		'label'   => esc_html__( 'Open social and sharing links in a new tab.', 'technico' ),
	) );

	$networks = technico_get_social_networks();

	foreach ( $networks as $network ) {
		$wpc->add_setting( 'social_' . $network['name'], array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		) );
		$wpc->add_control( 'social_' . $network['name'], array(
			'type'    => 'url',
			'section' => 'social',
			'label'   => esc_html( sprintf( _x( '%s URL', 'social network url', 'technico' ), $network['label'] ) ),
		) );
	}

	$wpc->add_setting( 'rss_feed', array(
		'default'           => get_bloginfo( 'rss2_url' ),
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( 'rss_feed', array(
		'type'    => 'url',
		'section' => 'social',
		'label'   => esc_html__( 'RSS Feed', 'technico' ),
	) );



	//
	// Listing Post
	//
	$wpc->add_setting( 'listing_post_date', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_date', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show date.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_post_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_categories', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show categories.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_post_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_comments', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show comments.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_post_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_featured', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show featured image.', 'technico' ),
	) );



	//
	// Single Post
	//
	$wpc->add_setting( 'single_date', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_date', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show date.', 'technico' ),
	) );

	$wpc->add_setting( 'single_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show categories.', 'technico' ),
	) );

	$wpc->add_setting( 'single_tags', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_tags', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show tags.', 'technico' ),
	) );


	$wpc->add_setting( 'single_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show comments.', 'technico' ),
	) );

	$wpc->add_setting( 'single_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_featured', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show featured image.', 'technico' ),
	) );



	//
	// Listing DIY
	//
	$wpc->add_setting( 'listing_diy_date', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_date', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show date.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_diy_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_categories', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show categories.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_diy_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_comments', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show comments.', 'technico' ),
	) );

	$wpc->add_setting( 'listing_diy_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_featured', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show featured image.', 'technico' ),
	) );



	//
	// Single DIY
	//
	$wpc->add_setting( 'single_diy_date', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_date', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show date.', 'technico' ),
	) );

	$wpc->add_setting( 'single_diy_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show categories.', 'technico' ),
	) );

	$wpc->add_setting( 'single_diy_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show comments.', 'technico' ),
	) );

	$wpc->add_setting( 'single_diy_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_featured', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show featured image.', 'technico' ),
	) );



	//
	// Titles
	//
	$wpc->add_setting( 'title_blog', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_blog', array(
		'type'        => 'text',
		'section'     => 'titles',
		'label'       => esc_html__( 'Blog section title', 'technico' ),
		'description' => wp_kses( __( "If provided, this option will override the page title, if you have set a <strong>Posts page</strong> in Settings > Reading > Front page displays.", 'technico' ), technico_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'title_blog_subtitle', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_blog_subtitle', array(
		'type'        => 'text',
		'section'     => 'titles',
		'label'       => esc_html__( 'Blog section subtitle', 'technico' ),
		'description' => wp_kses( __( "If provided, this option will override the page subtitle, if you have set a <strong>Posts page</strong> in Settings > Reading > Front page displays.", 'technico' ), technico_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'title_diy', array(
		'default'           => esc_html__( 'do it yourself.', 'technico' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_diy', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( 'DIY title', 'technico' ),
	) );

	$wpc->add_setting( 'title_search', array(
		'default'           => esc_html__( 'search results.', 'technico' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_search', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( 'Search title', 'technico' ),
	) );

	$wpc->add_setting( 'title_404', array(
		'default'           => esc_html__( 'page not found.', 'technico' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_404', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( '404 (not found) title', 'technico' ),
	) );



	//
	// Footer
	//
	$wpc->add_setting( 'footer_back_to_top', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'footer_back_to_top', array(
		'type'    => 'checkbox',
		'section' => 'footer',
		'label'   => esc_html__( 'Show floating "Back to top" button.', 'technico' ),
	) );

	$wpc->add_setting( 'footer_text', array(
		'default'           => technico_get_default_footer_text(),
		'sanitize_callback' => 'technico_sanitize_footer_text',
	) );
	$wpc->add_control( 'footer_text', array(
		'type'        => 'text',
		'section'     => 'footer',
		'label'       => esc_html__( 'Footer text left', 'technico' ),
		'description' => esc_html__( 'Allowed tags: a (href|class), img (src|class), span (class), i (class), b, em, strong.', 'technico' ),
	) );

	$wpc->add_setting( 'footer_text_right', array(
		'default'           => technico_get_default_footer_text( 'right' ),
		'sanitize_callback' => 'technico_sanitize_footer_text',
	) );
	$wpc->add_control( 'footer_text_right', array(
		'type'        => 'text',
		'section'     => 'footer',
		'label'       => esc_html__( 'Footer text right', 'technico' ),
		'description' => esc_html__( 'Allowed tags: a (href|class), img (src|class), span (class), i (class), b, em, strong.', 'technico' ),
	) );



	//
	// Other
	//
	$wpc->add_setting( 'custom_css', array(
		'default'              => '',
		'sanitize_callback'    => 'technico_sanitize_custom_css',
		'sanitize_js_callback' => 'technico_sanitize_custom_css',
	) );
	$wpc->add_control( 'custom_css', array(
		'type'    => 'textarea',
		'section' => 'other',
		'label'   => esc_html__( 'Custom CSS', 'technico' ),
	) );

	$wpc->add_setting( 'google_anaytics_tracking_id', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'google_anaytics_tracking_id', array(
		'type'        => 'text',
		'section'     => 'other',
		'label'       => esc_html__( 'Google Analytics Tracking ID', 'technico' ),
		'description' => wp_kses( sprintf( __( 'Tracking is enabled only for the non-admin portion of your website. If you need fine-grained control of the tracking code, you are strongly adviced to <a href="%s" target="_blank">use a specialty plugin</a> instead.', 'technico' ), 'https://wordpress.org/plugins/search.php?q=analytics' ), technico_get_allowed_tags( 'guide' ) ),
	) );



	//
	// title_tagline Section
	//
	$wpc->add_setting( 'show_site_title', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'show_site_title', array(
		'type'     => 'checkbox',
		'section'  => 'title_tagline',
		'priority' => 8,
		'label'    => esc_html__( 'Show site title.', 'technico' ),
	) );

	$wpc->add_setting( 'show_site_tagline', array(
		'default'           => 1,
		'sanitize_callback' => 'technico_sanitize_checkbox',
	) );
	$wpc->add_control( 'show_site_tagline', array(
		'type'     => 'checkbox',
		'section'  => 'title_tagline',
		'priority' => 8,
		'label'    => esc_html__( 'Show site tagline.', 'technico' ),
	) );

}

add_action( 'customize_register', 'technico_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function technico_customize_register_custom_controls( $wpc ) {
	require get_template_directory() . '/inc/customizer-controls/static-text.php';
}
