<?php
if ( ! class_exists( 'CI_Widget_Contact_Info' ) ):
	class CI_Widget_Contact_Info extends WP_Widget {

		protected $defaults = array(
			'title' => '',
			'map'   => '',
			'name'  => '',
			'rows'  => array(),
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Display a map and contact information.', 'technico' ) );
			$control_ops = array();
			parent::__construct( 'ci-contact-info', $name = esc_html__( 'Theme - Contact', 'technico' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = $args['id'];
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$map  = $instance['map'];
			$name = $instance['name'];
			$rows = $instance['rows'];

			echo $before_widget;

			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			if ( $map ) {
				?><div class="ci-map-wrap"><?php echo $map; ?></div><?php
			}

			if ( ! empty( $name ) || ! empty( $rows ) ) {
				?>
				<ul class="module-contact-info">
					<?php if ( $name ): ?>
						<li class="module-contact-info-title"><?php echo $name; ?></li>
					<?php endif; ?>

					<?php foreach( $rows as $row ): ?>
						<li>
							<?php if ( ! empty( $row['icon'] ) ): ?>
								<i class="fa <?php echo esc_attr( $row['icon'] ); ?>"></i>
							<?php endif; ?>

							<?php if ( ! empty( $row['text'] ) ): ?>
								<span><?php echo $row['text']; ?></span>
							<?php endif; ?>

						</li>
					<?php endforeach; ?>
				</ul>
				<?php
			}

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );
			$instance['map']   = wp_kses( $new_instance['map'], array( 'iframe' => array( 'src' => true, 'width' => true, 'height' => true, 'frameborder' => true, 'style' => true, 'allowfullscreen' => true ) ) );
			$instance['name']  = sanitize_text_field( $new_instance['name'] );
			$instance['rows']  = $this->sanitize_instance_rows( $new_instance );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = $instance['title'];
			$map   = $instance['map'];
			$name  = $instance['name'];
			$rows  = $instance['rows'];

			$row_icon_name = $this->get_field_name( 'row_icon' ) . '[]';
			$row_text_name = $this->get_field_name( 'row_text' ) . '[]';
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>

			<p><?php echo wp_kses( __( 'In order to display a map, you need to provide an embed code. Visit Google Maps, select the place of interest and press the "Share" button. Then select "Embed map" and copy/paste the code that starts with <code>&lt;iframe</code>.', 'technico' ), technico_get_allowed_tags( 'guide' ) ); ?></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'map' ) ); ?>"><?php esc_html_e( 'Map embed code:', 'technico' ); ?></label><textarea id="<?php echo esc_attr( $this->get_field_id( 'map' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'map' ) ); ?>" class="widefat"><?php echo esc_textarea( $map ); ?></textarea></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>"><?php esc_html_e( 'Contact name:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'name' ) ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>" class="widefat" /></p>

			<p><?php esc_html_e( 'Add as many items as you want by pressing the "Add Item" button. Remove any item by selecting "Remove me".', 'technico' ); ?></p>
			<p><?php echo wp_kses( sprintf( __( 'In the Icon code field, type the icon code that best describes your item, including the <em>fa-</em> prefix. E.g. <code>fa-map-marker</code>. <a href="%s" target="_blank">Reference</a>', 'technico' ), 'http://fontawesome.io/icons/' ), technico_get_allowed_tags( 'guide' ) ); ?></p>
			<fieldset class="ci-repeating-fields">
				<div class="inner">
					<?php
						if ( ! empty( $rows ) ) {
							$count = count( $rows );
							for ( $i = 0; $i < $count; $i ++ ) {
								?>
								<div class="post-field">
									<label class="post-field-item"><?php esc_html_e( 'Icon code:', 'technico' ); ?>
										<input type="text" name="<?php echo esc_attr( $row_icon_name ); ?>" value="<?php echo esc_attr( $rows[$i]['icon'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Text:', 'technico' ); ?>
										<input type="text" name="<?php echo esc_attr( $row_text_name ); ?>" value="<?php echo esc_attr( $rows[$i]['text'] ); ?>" class="widefat" />
									</label>

									<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
								</div>
								<?php
							}
						}
					?>
					<?php
					//
					// Add an empty and hidden set for jQuery
					//
					?>
					<div class="post-field field-prototype" style="display: none;">
						<label class="post-field-item"><?php esc_html_e( 'Icon code:', 'technico' ); ?>
							<input type="text" name="<?php echo esc_attr( $row_icon_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Text:', 'technico' ); ?>
							<input type="text" name="<?php echo esc_attr( $row_text_name ); ?>" value="" class="widefat" />
						</label>

						<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
					</div>
				</div>
				<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Item', 'technico' ); ?></a>
			</fieldset>
			<?php
		} // form

		protected function sanitize_instance_rows( $instance ) {
			if ( empty( $instance ) || ! is_array( $instance ) ) {
				return array();
			}

			$icons = $instance['row_icon'];
			$texts = $instance['row_text'];

			$count = max(
				count( $icons ),
				count( $texts )
			);

			$new_fields = array();

			$records_count = 0;

			for ( $i = 0; $i < $count; $i++ ) {
				if ( empty( $icons[ $i ] ) && empty( $texts[ $i ] ) ) {
					continue;
				}

				$new_fields[ $records_count ]['icon'] = sanitize_html_class( $icons[ $i ] );
				$new_fields[ $records_count ]['text'] = wp_kses( $texts[ $i ], technico_get_allowed_tags() );

				$records_count++;
			}
			return $new_fields;
		}

	} // class

	register_widget( 'CI_Widget_Contact_Info' );

endif;