<?php
if ( ! class_exists( 'CI_Widget_Latest_Posts' ) ):
	class CI_Widget_Latest_Posts extends WP_Widget {

		protected $defaults = array(
			'title'             => '',
			'subtitle'          => '',
			'category'          => '',
			'exclude'           => '',
			'random'            => '',
			'count'             => 3,
			'layout'            => 'thumb',
			'align'             => 'left',
			'text_color'        => '',
			'background_color'  => '',
			'background_image'  => '',
			'background_repeat' => 'repeat',
			'extra_padding'     => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Latest or random posts, optionally from a specific category.', 'technico' ) );
			$control_ops = array( 'width' => 400 );
			parent::__construct( 'ci-latest-posts', $name = esc_html__( 'Theme - Latest Posts', 'technico' ), $widget_ops, $control_ops );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_custom_css' ) );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = $args['id'];
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$subtitle = $instance['subtitle'];
			$category = $instance['category'];
			$exclude  = $instance['exclude'];
			$random   = $instance['random'];
			$count    = $instance['count'];
			$layout   = $instance['layout'];
			$align    = $instance['align'];

			if ( 0 == $count ) {
				return;
			}

			$query_args = array(
				'orderby'        => 'date',
				'order'          => 'DESC',
				'posts_per_page' => $count
			);

			if ( 1 == $random ) {
				$query_args['orderby'] = 'rand';
				unset( $query_args['order'] );
			}

			if ( ! empty( $category ) && $category > 0 ) {
				$query_args['cat'] = intval( $category );
			}

			if ( ! empty( $exclude ) ) {
				$query_args['category__not_in'] = $exclude;
			}

			$q = new WP_Query( $query_args );


			$background_color = $instance['background_color'];
			$background_image = $instance['background_image'];
			$extra_padding    = $instance['extra_padding'] == 1 ? 'wrap-extra-pad' : '';

			if ( ! empty( $background_color ) || ! empty( $background_image ) ) {
				preg_match( '/class=(["\']).*?widget.*?\1/', $before_widget, $match );
				if ( ! empty( $match ) ) {
					$attr_class    = preg_replace( '/\bwidget\b/', 'widget widget-padded', $match[0], 1 );
					$before_widget = str_replace( $match[0], $attr_class, $before_widget );
				}
			}

			$column_classes = technico_get_columns_classes( technico_best_number_of_columns( $q->post_count ), true );

			echo $before_widget;

			?><div class="widget-wrap <?php echo esc_attr( $extra_padding ); ?>"><?php

			if ( in_array( $id, technico_get_fullwidth_sidebars() ) ) {
				?>
				<div class="container">
					<div class="row">
						<div class="col-xs-12">
				<?php
			}

			if ( $title || $subtitle ) {
				?><div class="section-title-wrap"><?php
				if ( $title ) {
					echo $args['before_title'] . $title . $args['after_title'];
				}

				if ( $subtitle ) {
					?><p class="section-subtitle"><?php echo esc_html( $subtitle ); ?></p><?php
				}
				?></div><?php
			}

			?><div class="row row-equal row-items"><?php

			if ( $q->have_posts() ) {
				while ( $q->have_posts() ) {
					$q->the_post();
					?>
					<div class="<?php echo esc_attr( $column_classes . ' text-' . $align ); ?>">
						<?php get_template_part( 'item-' . $layout, get_post_type() ); ?>
					</div>
					<?php
				}
				wp_reset_postdata();
			}

			?></div><?php

			if ( in_array( $id, technico_get_fullwidth_sidebars() ) ) {
				?>
						</div>
					</div>
				</div>
				<?php
			}

			?></div><?php

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']    = sanitize_text_field( $new_instance['title'] );
			$instance['subtitle'] = sanitize_text_field( $new_instance['subtitle'] );
			$instance['category'] = technico_sanitize_intval_or_empty( $new_instance['category'] );
			$instance['random']   = technico_sanitize_checkbox( $new_instance['random'] );
			$instance['count']    = absint( $new_instance['count'] ) > 0 ? absint( $new_instance['count'] ) : $this->defaults['count'];
			$instance['layout']   = array_key_exists( $new_instance['layout'], technico_get_listing_item_layouts( 'post' ) ) ? $new_instance['layout'] : $this->defaults['layout'];
			$instance['align']    = in_array( $new_instance['align'], array( 'left', 'center' ) ) ? $new_instance['align'] : $this->defaults['align'];

			if ( ! empty( $new_instance['exclude'] ) && is_array( $new_instance['exclude'] ) ) {
				$exclude = $new_instance['exclude'];
				$exclude = array_map( 'intval', $exclude );
				$exclude = array_filter( $exclude );

				$instance['exclude'] = $exclude;
			} else {
				$instance['exclude'] = array();
			}


			$instance['text_color']        = technico_sanitize_hex_color( $new_instance['text_color'] );
			$instance['background_color']  = technico_sanitize_hex_color( $new_instance['background_color'] );
			$instance['background_image']  = esc_url_raw( $new_instance['background_image'] );
			$instance['background_repeat'] = in_array( $new_instance['background_repeat'], array( 'repeat', 'no-repeat', 'repeat-x', 'repeat-y' ) ) ? $new_instance['background_repeat'] : 'repeat';
			$instance['extra_padding']     = technico_sanitize_checkbox_ref( $new_instance['extra_padding'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title    = $instance['title'];
			$subtitle = $instance['subtitle'];
			$category = $instance['category'];
			$exclude  = $instance['exclude'];
			$random   = $instance['random'];
			$count    = $instance['count'];
			$layout   = $instance['layout'];
			$align    = $instance['align'];

			$text_color        = $instance['text_color'];
			$background_color  = $instance['background_color'];
			$background_image  = $instance['background_image'];
			$background_repeat = $instance['background_repeat'];
			$extra_padding     = $instance['extra_padding'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>"><?php esc_html_e( 'Subtitle:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtitle' ) ); ?>" type="text" value="<?php echo esc_attr( $subtitle ); ?>" class="widefat" /></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Category to display the latest posts from (optional):', 'technico' ); ?></label>
			<?php wp_dropdown_categories( array(
				'taxonomy'          => 'category',
				'show_option_all'   => '',
				'show_option_none'  => ' ',
				'option_none_value' => '',
				'show_count'        => 1,
				'echo'              => 1,
				'selected'          => $category,
				'hierarchical'      => 1,
				'name'              => $this->get_field_name( 'category' ),
				'id'                => $this->get_field_id( 'category' ),
				'class'             => 'postform widefat',
			) ); ?>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'exclude' ) ); ?>"><?php esc_html_e( 'Categories to exclude latest posts from (optional):', 'technico' ); ?></label>
			<ul class="exclude-category">
			<?php
				$terms_dd = wp_terms_checklist( 0, array(
					'taxonomy'      => 'category',
					'selected_cats' => $exclude,
					'checked_ontop' => false,
					'echo'          => false,
				) );
				$terms_dd = str_replace( 'post_category[]', $this->get_field_name( 'exclude[]' ), $terms_dd );
				echo $terms_dd;
			?>
			</ul>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'random' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'random' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'random' ) ); ?>" value="1" <?php checked( $random, 1 ); ?> /><?php esc_html_e( 'Show random posts.', 'technico' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'count' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'count' ) ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $count ); ?>" class="widefat"/></p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Item appearance:', 'technico' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>">
					<?php $choices = technico_get_listing_item_layouts( 'post' ); ?>
					<?php foreach ( $choices as $value => $description ): ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $layout ); ?>><?php echo strip_tags( $description ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>"><?php esc_html_e( 'Text align:', 'technico' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'align' ) ); ?>">
					<?php $choices = array(
						'left'   => _x( 'Left', 'text align', 'technico' ),
						'center' => _x( 'Center', 'text align', 'technico' ),
					); ?>
					<?php foreach ( $choices as $value => $description ): ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $align ); ?>><?php echo strip_tags( $description ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>


			<fieldset class="ci-collapsible">
				<legend><?php esc_html_e( 'Customize', 'technico' ); ?> <i class="dashicons dashicons-arrow-down"></i></legend>
				<div class="elements">
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php esc_html_e( 'Text Color:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" type="text" value="<?php echo esc_attr( $text_color ); ?>" class="colorpckr widefat"/></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>"><?php esc_html_e( 'Background Color:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_color' ) ); ?>" type="text" value="<?php echo esc_attr( $background_color ); ?>" class="colorpckr widefat"/></p>

					<p class="ci-collapsible-media"><label for="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>"><?php esc_html_e( 'Background Image:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_image' ) ); ?>" type="text" value="<?php echo esc_attr( $background_image ); ?>" class="ci-uploaded-url widefat"/><a href="#" class="button ci-media-button"><?php esc_html_e( 'Select', 'technico' ); ?></a></p>
					<p>
						<label for="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>"><?php esc_html_e( 'Background Repeat:', 'technico' ); ?></label>
						<select id="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'background_repeat' ) ); ?>">
							<option value="repeat" <?php selected( 'repeat', $background_repeat ); ?>><?php esc_html_e( 'Repeat', 'technico' ); ?></option>
							<option value="repeat-x" <?php selected( 'repeat-x', $background_repeat ); ?>><?php esc_html_e( 'Repeat Horizontally', 'technico' ); ?></option>
							<option value="repeat-y" <?php selected( 'repeat-y', $background_repeat ); ?>><?php esc_html_e( 'Repeat Vertically', 'technico' ); ?></option>
							<option value="no-repeat" <?php selected( 'no-repeat', $background_repeat ); ?>><?php esc_html_e( 'No Repeat', 'technico' ); ?></option>
						</select>
					</p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'extra_padding' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>" value="1" <?php checked( $extra_padding, 1 ); ?> /><?php esc_html_e( 'Apply extra padding.', 'technico' ); ?></label></p>
				</div>
			</fieldset>

			<?php
		} // form

		function enqueue_custom_css() {
			$settings = $this->get_settings();

			if ( empty( $settings ) ) {
				return;
			}

			foreach ( $settings as $instance_id => $instance ) {
				$id = $this->id_base . '-' . $instance_id;

				if ( ! is_active_widget( false, $id, $this->id_base ) ) {
					continue;
				}

				$instance = wp_parse_args( (array) $instance, $this->defaults );

				$sidebar_id      = false; // Holds the sidebar id that the widget is assigned to.
				$sidebar_widgets = wp_get_sidebars_widgets();
				if ( ! empty( $sidebar_widgets ) ) {
					foreach ( $sidebar_widgets as $sidebar => $widgets ) {
						// We need to check $widgets for emptiness due to https://core.trac.wordpress.org/ticket/14876
						if ( ! empty( $widgets ) && array_search( $id, $widgets ) !== false ) {
							$sidebar_id = $sidebar;
						}
					}
				}

				$text_color        = $instance['text_color'];
				$background_color  = $instance['background_color'];
				$background_image  = $instance['background_image'];
				$background_repeat = $instance['background_repeat'];

				$css         = '';
				$padding_css = '';

				if ( ! empty( $text_color ) ) {
					$css .= 'color: ' . $text_color . '; ';
				}
				if ( ! empty( $background_color ) ) {
					$css .= 'background-color: ' . $background_color . '; ';
				}
				if ( ! empty( $background_image ) ) {
					$css .= 'background-image: url(' . esc_url( $background_image ) . ');';
					$css .= 'background-repeat: ' . $background_repeat . ';';
				}

				if ( ! empty( $css ) || ! empty( $padding_css ) ) {
					$css = '#' . $id . ' .widget-wrap { ' . $css . $padding_css . ' } ' . PHP_EOL;
					wp_add_inline_style( 'technico-style', $css );
				}

			}

		}

	} // class

	register_widget( 'CI_Widget_Latest_Posts' );

endif;
