<?php
if ( ! class_exists( 'CI_Widget_Post_Type_Items' ) ):
	class CI_Widget_Post_Type_Items extends WP_Widget {

		public $ajax_posts   = 'technico_post_type_items_widget_post_type_ajax_get_posts';
		public $ajax_layouts = 'technico_post_type_items_widget_post_type_ajax_get_layouts';

		protected $defaults = array(
			'title'             => '',
			'subtitle'          => '',
			'post_type'         => 'post',
			'rows'              => array(),
			'layout'            => 'thumb',
			'align'             => 'left',
			'text_color'        => '',
			'background_color'  => '',
			'background_image'  => '',
			'background_repeat' => 'repeat',
			'extra_padding'     => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Displays a hand-picked selection of posts from a selected post type.', 'technico' ) );
			$control_ops = array( 'width' => 400 );
			parent::__construct( 'ci-post-type-items', $name = esc_html__( 'Theme - Post Type Items', 'technico' ), $widget_ops, $control_ops );

			if ( is_admin() === true ) {
				add_action( 'wp_ajax_' . $this->ajax_posts, 'CI_Widget_Post_Type_Items::_ajax_get_posts' );
				add_action( 'wp_ajax_' . $this->ajax_layouts, 'CI_Widget_Post_Type_Items::_ajax_get_layouts' );
			}

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_custom_css' ) );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = $args['id'];
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$subtitle  = $instance['subtitle'];
			$post_type = $instance['post_type'];
			$rows      = $instance['rows'];
			$layout    = $instance['layout'];
			$align     = $instance['align'];


			if ( empty( $post_type ) or empty( $rows ) ) {
				return;
			}


			$background_color = $instance['background_color'];
			$background_image = $instance['background_image'];
			$extra_padding    = $instance['extra_padding'] == 1 ? 'wrap-extra-pad' : '';

			if ( ! empty( $background_color ) || ! empty( $background_image ) ) {
				preg_match( '/class=(["\']).*?widget.*?\1/', $before_widget, $match );
				if ( ! empty( $match ) ) {
					$attr_class    = preg_replace( '/\bwidget\b/', 'widget widget-padded', $match[0], 1 );
					$before_widget = str_replace( $match[0], $attr_class, $before_widget );
				}
			}

			$ids = wp_list_pluck( $rows, 'post_id' );
			$ids = array_filter( $ids );

			$q = new WP_Query( array(
				'post_type'      => $post_type,
				'posts_per_page' => - 1,
				'post__in'       => $ids,
				'orderby'        => 'post__in',
			) );

			$column_classes = technico_get_columns_classes( technico_best_number_of_columns( $q->post_count ), true );

			echo $before_widget;

			?><div class="widget-wrap <?php echo esc_attr( $extra_padding ); ?>"><?php

			if ( in_array( $id, technico_get_fullwidth_sidebars() ) ) {
				?>
				<div class="container">
					<div class="row">
						<div class="col-xs-12">
				<?php
			}

			if ( $title || $subtitle ) {
				?><div class="section-title-wrap"><?php
				if ( $title ) {
					echo $args['before_title'] . $title . $args['after_title'];
				}

				if ( $subtitle ) {
					?><p class="section-subtitle"><?php echo esc_html( $subtitle ); ?></p><?php
				}
				?></div><?php
			}

			?><div class="row row-equal row-items"><?php

			if ( $q->have_posts() ) {
				while ( $q->have_posts() ) {
					$q->the_post();
					?>
					<div class="<?php echo esc_attr( $column_classes . ' text-' . $align ); ?>">
						<?php get_template_part( 'item-' . $layout, get_post_type() ); ?>
					</div>
					<?php
				}
				wp_reset_postdata();
			}

			?></div><?php

			if ( in_array( $id, technico_get_fullwidth_sidebars() ) ) {
				?>
						</div>
					</div>
				</div>
				<?php
			}

			?></div><?php

			echo $after_widget;
		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']     = sanitize_text_field( $new_instance['title'] );
			$instance['subtitle']  = sanitize_text_field( $new_instance['subtitle'] );
			$instance['post_type'] = in_array( $new_instance['post_type'], $this->get_available_post_types( 'names' ), true ) ? $new_instance['post_type'] : $this->defaults['post_type'];
			$instance['rows']      = $this->sanitize_instance_rows( $new_instance );
			$instance['layout']    = array_key_exists( $new_instance['layout'], technico_get_listing_item_layouts( $instance['post_type'] ) ) ? $new_instance['layout'] : $this->defaults['layout'];
			$instance['align']     = in_array( $new_instance['align'], array( 'left', 'center' ) ) ? $new_instance['align'] : $this->defaults['align'];

			$instance['text_color']        = technico_sanitize_hex_color( $new_instance['text_color'] );
			$instance['background_color']  = technico_sanitize_hex_color( $new_instance['background_color'] );
			$instance['background_image']  = esc_url_raw( $new_instance['background_image'] );
			$instance['background_repeat'] = in_array( $new_instance['background_repeat'], array( 'repeat', 'no-repeat', 'repeat-x', 'repeat-y' ) ) ? $new_instance['background_repeat'] : 'repeat';
			$instance['extra_padding']     = technico_sanitize_checkbox_ref( $new_instance['extra_padding'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title     = $instance['title'];
			$subtitle  = $instance['subtitle'];
			$post_type = $instance['post_type'];
			$rows      = $instance['rows'];
			$layout    = $instance['layout'];
			$align     = $instance['align'];

			$text_color        = $instance['text_color'];
			$background_color  = $instance['background_color'];
			$background_image  = $instance['background_image'];
			$background_repeat = $instance['background_repeat'];
			$extra_padding     = $instance['extra_padding'];

			$cpts_available   = $this->get_available_post_types();
			$row_post_id_name = $this->get_field_name( 'row_post_id' ) . '[]';
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>"><?php esc_html_e( 'Subtitle:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtitle' ) ); ?>" type="text" value="<?php echo esc_attr( $subtitle ); ?>" class="widefat" /></p>

			<p data-ajaxposts="<?php echo esc_attr( $this->ajax_posts ); ?>" data-ajaxlayouts="<?php echo esc_attr( $this->ajax_layouts ); ?>">
				<label for="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>"><?php esc_html_e( 'Post type:', 'technico' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'post_type' ) ); ?>" class="widefat ci-items-post-type">
					<?php foreach ( $cpts_available as $key => $pt ) {
						?><option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $post_type ); ?>><?php echo esc_html( $pt->labels->name ); ?></option><?php
					} ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Item appearance:', 'technico' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat ci-items-layout">
					<?php $choices = technico_get_listing_item_layouts( $post_type ); ?>
					<?php foreach ( $choices as $value => $description ): ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $layout ); ?>><?php echo strip_tags( $description ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>"><?php esc_html_e( 'Text align:', 'technico' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'align' ) ); ?>">
					<?php $choices = array(
						'left'   => _x( 'Left', 'text align', 'technico' ),
						'center' => _x( 'Center', 'text align', 'technico' ),
					); ?>
					<?php foreach ( $choices as $value => $description ): ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $align ); ?>><?php echo strip_tags( $description ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p><?php esc_html_e( 'Add as many items as you want by pressing the "Add Item" button. Remove any item by selecting "Remove me".', 'technico' ); ?></p>
			<fieldset class="ci-repeating-fields">
				<div class="inner">
					<?php
						if ( ! empty( $rows ) ) {
							$count = count( $rows );
							for ( $i = 0; $i < $count; $i ++ ) {
								?>
								<div class="post-field">
									<label class="post-field-item" data-value="<?php echo esc_attr( $rows[ $i ]['post_id'] ); ?>"><?php esc_html_e( 'Item:', 'technico' ); ?>
										<?php
											technico_dropdown_posts( array(
												'post_type'            => $post_type,
												'selected'             => $rows[ $i ]['post_id'],
												'class'                => 'widefat posts_dropdown',
												'show_option_none'     => '&nbsp;',
												'select_even_if_empty' => true,
											), $row_post_id_name );
										?>
									</label>

									<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
								</div>
								<?php
							}
						}
					?>
					<?php
					//
					// Add an empty and hidden set for jQuery
					//
					?>
					<div class="post-field field-prototype" style="display: none;">
						<label class="post-field-item"><?php esc_html_e( 'Item:', 'technico' ); ?>
							<?php
								technico_dropdown_posts( array(
									'post_type'            => $post_type,
									'class'                => 'widefat posts_dropdown',
									'show_option_none'     => '&nbsp;',
									'select_even_if_empty' => true,
								), $row_post_id_name );
							?>
						</label>

						<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'technico' ); ?></a></p>
					</div>
				</div>
				<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Item', 'technico' ); ?></a>
			</fieldset>

			<fieldset class="ci-collapsible">
				<legend><?php esc_html_e( 'Customize', 'technico' ); ?> <i class="dashicons dashicons-arrow-down"></i></legend>
				<div class="elements">
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php esc_html_e( 'Text Color:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" type="text" value="<?php echo esc_attr( $text_color ); ?>" class="colorpckr widefat"/></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>"><?php esc_html_e( 'Background Color:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_color' ) ); ?>" type="text" value="<?php echo esc_attr( $background_color ); ?>" class="colorpckr widefat"/></p>

					<p class="ci-collapsible-media"><label for="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>"><?php esc_html_e( 'Background Image:', 'technico' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_image' ) ); ?>" type="text" value="<?php echo esc_attr( $background_image ); ?>" class="ci-uploaded-url widefat"/><a href="#" class="button ci-media-button"><?php esc_html_e( 'Select', 'technico' ); ?></a></p>
					<p>
						<label for="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>"><?php esc_html_e( 'Background Repeat:', 'technico' ); ?></label>
						<select id="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'background_repeat' ) ); ?>">
							<option value="repeat" <?php selected( 'repeat', $background_repeat ); ?>><?php esc_html_e( 'Repeat', 'technico' ); ?></option>
							<option value="repeat-x" <?php selected( 'repeat-x', $background_repeat ); ?>><?php esc_html_e( 'Repeat Horizontally', 'technico' ); ?></option>
							<option value="repeat-y" <?php selected( 'repeat-y', $background_repeat ); ?>><?php esc_html_e( 'Repeat Vertically', 'technico' ); ?></option>
							<option value="no-repeat" <?php selected( 'no-repeat', $background_repeat ); ?>><?php esc_html_e( 'No Repeat', 'technico' ); ?></option>
						</select>
					</p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'extra_padding' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>" value="1" <?php checked( $extra_padding, 1 ); ?> /><?php esc_html_e( 'Apply extra padding.', 'technico' ); ?></label></p>
				</div>
			</fieldset>
			<?php
		}

		protected function sanitize_instance_rows( $instance ) {
			if ( empty( $instance ) || ! is_array( $instance ) ) {
				return array();
			}

			$ids = $instance['row_post_id'];

			$count = count( $ids );

			$new_fields = array();

			$records_count = 0;

			for ( $i = 0; $i < $count; $i++ ) {
				if ( empty( $ids[ $i ] ) ) {
					continue;
				}

				$new_fields[ $records_count ]['post_id'] = ! empty( $ids[ $i ] ) ? intval( $ids[ $i ] ) : '';

				$records_count++;
			}
			return $new_fields;
		}


		protected function get_available_post_types( $return = 'objects' ) {
			$return = in_array( $return, array( 'objects', 'names' ), true ) ? $return : 'objects';

			$post_types = get_post_types( array(
				'public' => true,
			), $return );

			unset( $post_types['attachment'] );
			unset( $post_types['technico_faq'] );

			return $post_types;
		}

		static function _ajax_get_posts() {
			$post_type_name = sanitize_key( $_POST['post_type_name'] );
			$name_field     = esc_attr( $_POST['name_field'] );

			$str = technico_dropdown_posts( array(
				'echo'                 => false,
				'post_type'            => $post_type_name,
				'class'                => 'widefat posts_dropdown',
				'show_option_none'     => '&nbsp;',
				'select_even_if_empty' => true,
			), $name_field );

			echo $str;
			die;
		}

		static function _ajax_get_layouts() {
			$post_type  = sanitize_key( $_POST['post_type_name'] );
			$layout     = sanitize_key( $_POST['layout_value'] );
			$name_field = esc_attr( $_POST['name_field'] );
			$id_field   = esc_attr( $_POST['id_field'] );

			?>
			<select id="<?php echo $id_field; ?>" class="widefat" name="<?php echo $name_field; ?>">
				<?php $choices = technico_get_listing_item_layouts( $post_type ); ?>
				<?php foreach ( $choices as $value => $description ): ?>
					<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $layout ); ?>><?php echo strip_tags( $description ); ?></option>
				<?php endforeach; ?>
			</select>
			<?php
			die;
		}

		function enqueue_custom_css() {
			$settings = $this->get_settings();

			if ( empty( $settings ) ) {
				return;
			}

			foreach ( $settings as $instance_id => $instance ) {
				$id = $this->id_base . '-' . $instance_id;

				if ( ! is_active_widget( false, $id, $this->id_base ) ) {
					continue;
				}

				$instance = wp_parse_args( (array) $instance, $this->defaults );

				$sidebar_id      = false; // Holds the sidebar id that the widget is assigned to.
				$sidebar_widgets = wp_get_sidebars_widgets();
				if ( ! empty( $sidebar_widgets ) ) {
					foreach ( $sidebar_widgets as $sidebar => $widgets ) {
						// We need to check $widgets for emptiness due to https://core.trac.wordpress.org/ticket/14876
						if ( ! empty( $widgets ) && array_search( $id, $widgets ) !== false ) {
							$sidebar_id = $sidebar;
						}
					}
				}

				$text_color        = $instance['text_color'];
				$background_color  = $instance['background_color'];
				$background_image  = $instance['background_image'];
				$background_repeat = $instance['background_repeat'];

				$css         = '';
				$padding_css = '';

				if ( ! empty( $text_color ) ) {
					$css .= 'color: ' . $text_color . '; ';
				}
				if ( ! empty( $background_color ) ) {
					$css .= 'background-color: ' . $background_color . '; ';
				}
				if ( ! empty( $background_image ) ) {
					$css .= 'background-image: url(' . esc_url( $background_image ) . ');';
					$css .= 'background-repeat: ' . $background_repeat . ';';
				}

				if ( ! empty( $css ) || ! empty( $padding_css ) ) {
					$css = '#' . $id . ' .widget-wrap { ' . $css . $padding_css . ' } ' . PHP_EOL;
					wp_add_inline_style( 'technico-style', $css );
				}

			}

		}

	} // class

	register_widget( 'CI_Widget_Post_Type_Items' );

endif;